@@ -47,6 +47,7 @@ module.exports = {
   sessionSecret: process.env.CMD_SESSION_SECRET,
   sessionLife: toIntegerConfig(process.env.CMD_SESSION_LIFE),
   tooBusyLag: toIntegerConfig(process.env.CMD_TOOBUSY_LAG),
+  documentMaxLength: toIntegerConfig(process.env.CMD_DOCUMENT_MAX_LENGTH),
   imageUploadType: process.env.CMD_IMAGE_UPLOAD_TYPE,
   imgur: {
     clientID: process.env.CMD_IMGUR_CLIENTID
@@ -156,5 +157,6 @@ module.exports = {
   allowEmailRegister: toBooleanConfig(process.env.CMD_ALLOW_EMAIL_REGISTER),
   allowGravatar: toBooleanConfig(process.env.CMD_ALLOW_GRAVATAR),
   openID: toBooleanConfig(process.env.CMD_OPENID),
-  linkifyHeaderStyle: process.env.CMD_LINKIFY_HEADER_STYLE
+  linkifyHeaderStyle: process.env.CMD_LINKIFY_HEADER_STYLE,
+  enableStatsApi: toBooleanConfig(process.env.CMD_ENABLE_STATS_API)
 }
