@@ -3,9 +3,14 @@
 const fs = require('fs')
 const path = require('path')
 
+function isPositiveAnswer (value) {
+  const lowerValue = value.toLowerCase()
+  return lowerValue === 'yes' || lowerValue === '1' || lowerValue === 'true'
+}
+
 exports.toBooleanConfig = function toBooleanConfig (configValue) {
   if (configValue && typeof configValue === 'string') {
-    return (configValue === 'true')
+    return (isPositiveAnswer(configValue))
   }
   return configValue
 }
