@@ -207,7 +207,7 @@ module.exports = function (sequelize, DataTypes) {
               const title = Note.parseNoteTitle(body)
               if (fsModifiedTime.isAfter(dbModifiedTime) && note.content !== body) {
                 note.update({
-                  title: title,
+                  title,
                   content: body,
                   lastchangeAt: fsModifiedTime
                 }).then(function (note) {
@@ -221,7 +221,7 @@ module.exports = function (sequelize, DataTypes) {
                       authorship = Note.updateAuthorshipByOperation(operations[i], null, authorship)
                     }
                     note.update({
-                      authorship: authorship
+                      authorship
                     }).then(function (note) {
                       return callback(null, note.id)
                     }).catch(function (err) {
