@@ -47,7 +47,7 @@ function sendDmpWorker (data, callback) {
   const cacheKey = Date.now() + '_' + shortId.generate()
   dmpCallbackCache[cacheKey] = callback
   data = Object.assign(data, {
-    cacheKey: cacheKey
+    cacheKey
   })
   dmpWorker.send(data)
 }
@@ -151,8 +151,8 @@ module.exports = function (sequelize, DataTypes) {
         if (count <= 0) return callback(null, null)
         sendDmpWorker({
           msg: 'get revision',
-          revisions: revisions,
-          count: count
+          revisions,
+          count
         }, callback)
       }).catch(function (err) {
         return callback(err, null)
@@ -272,7 +272,7 @@ module.exports = function (sequelize, DataTypes) {
           } else {
             Revision.create({
               noteId: note.id,
-              patch: patch,
+              patch,
               content: note.content,
               length: note.content.length,
               authorship: note.authorship
