@@ -363,13 +363,6 @@ function connectNextSocket () {
   }, 1)
 }
 
-function interruptConnection (socket, noteId, socketId) {
-  if (notes[noteId]) delete notes[noteId]
-  if (users[socketId]) delete users[socketId]
-  if (socket) { clearSocketQueue(connectionSocketQueue, socket) } else { connectionSocketQueue.shift() }
-  connectNextSocket()
-}
-
 function checkViewPermission (req, note) {
   if (note.permission === 'private') {
     if (req.user && req.user.logged_in && req.user.id === note.owner) { return true } else { return false }
@@ -386,13 +379,8 @@ let isDisconnectBusy = false
 const disconnectSocketQueue = []
 
 function finishConnection (socket, noteId, socketId) {
-  // if no valid info provided will drop the client
-  if (!socket || !notes[noteId] || !users[socketId]) {
-    return interruptConnection(socket, noteId, socketId)
-  }
   // check view permission
   if (!checkViewPermission(socket.request, notes[noteId])) {
-    interruptConnection(socket, noteId, socketId)
     return failConnection(403, 'connection forbidden', socket)
   }
   const note = notes[noteId]
@@ -460,6 +448,13 @@ function startConnection (socket) {
       },
       include
     }).then(function (note) {
+      // if client disconnected while we waited for the note, disconnect() cleaned up users[socket.id]
+      if (!users[socket.id]) {
+        clearSocketQueue(connectionSocketQueue, socket)
+        connectNextSocket()
+        return
+      }
+
       if (!note) {
         return failConnection(404, 'note not found', socket)
       }
