@@ -18,7 +18,7 @@ passport.use(new LocalStrategy({
   if (!validator.isEmail(email)) return done(null, false)
   models.User.findOne({
     where: {
-      email: email
+      email
     }
   }).then(function (user) {
     if (!user) return done(null, false)
