@@ -5,7 +5,7 @@ const errors = require('../../errors')
 const fs = require('fs')
 const path = require('path')
 
-exports.findNote = function (req, res, callback, include, createIfNotFound = true) {
+exports.findNote = function (req, res, callback, include = null, createIfNotFound = false) {
   const id = req.params.noteId || req.params.shortid
   models.Note.parseNoteId(id, function (err, _id) {
     if (err) {
@@ -60,17 +60,23 @@ exports.newNote = async function (req, res, body) {
     } else {
       return req.method === 'POST' ? errors.errorForbidden(res) : errors.errorNotFound(res)
     }
+
     try {
-      const count = await models.Note.count({
-        where: {
-          alias: req.alias
-        }
+      const id = await new Promise((resolve, reject) => {
+        models.Note.parseNoteId(noteId, (err, id) => {
+          if (err) {
+            reject(err)
+          } else {
+            resolve(id)
+          }
+        })
       })
-      if (count > 0) {
+
+      if (id) {
         return errors.errorConflict(res)
       }
-    } catch (err) {
-      logger.error('Error while checking for possible duplicate: ' + err)
+    } catch (error) {
+      logger.error(error)
       return errors.errorInternalError(res)
     }
   }
