@@ -1,37 +1,84 @@
-import 'codemirror/keymap/sublime'
-import 'codemirror/keymap/emacs'
-import 'codemirror/keymap/vim'
-import 'codemirror/mode/gfm/gfm'
-import 'codemirror/addon/mode/overlay.js'
-import 'codemirror/addon/mode/simple.js'
-import 'codemirror/addon/mode/multiplex.js'
-import 'codemirror/addon/selection/active-line.js'
-import 'codemirror/addon/search/searchcursor.js'
-import 'codemirror/addon/search/search.js'
-import 'codemirror/addon/search/jump-to-line.js'
-import 'codemirror/addon/search/matchesonscrollbar.js'
-import 'codemirror/addon/search/match-highlighter.js'
-import 'codemirror/addon/scroll/simplescrollbars.js'
-import 'codemirror/addon/scroll/annotatescrollbar.js'
-import 'codemirror/addon/display/panel.js'
-import 'codemirror/addon/display/placeholder.js'
-import 'codemirror/addon/display/fullscreen.js'
-import 'codemirror/addon/display/autorefresh.js'
-import 'codemirror/addon/dialog/dialog.js'
-import 'codemirror/addon/edit/matchbrackets.js'
-import 'codemirror/addon/edit/closebrackets.js'
-import 'codemirror/addon/edit/matchtags.js'
-import 'codemirror/addon/edit/closetag.js'
-import 'codemirror/addon/edit/continuelist.js'
-import 'codemirror/addon/comment/comment.js'
-import 'codemirror/addon/comment/continuecomment.js'
-import 'codemirror/addon/wrap/hardwrap.js'
-import 'codemirror/addon/fold/foldcode.js'
-import 'codemirror/addon/fold/brace-fold.js'
-import 'codemirror/addon/fold/foldgutter.js'
-import 'codemirror/addon/fold/markdown-fold.js'
-import 'codemirror/addon/fold/xml-fold.js'
-import 'codemirror/addon/merge/merge.js'
+import '@hedgedoc/codemirror-5/addon/comment/comment.js'
+import '@hedgedoc/codemirror-5/addon/comment/continuecomment.js'
+import '@hedgedoc/codemirror-5/addon/dialog/dialog.js'
+import '@hedgedoc/codemirror-5/addon/display/autorefresh.js'
+import '@hedgedoc/codemirror-5/addon/display/fullscreen.js'
+import '@hedgedoc/codemirror-5/addon/display/panel.js'
+import '@hedgedoc/codemirror-5/addon/display/placeholder.js'
+import '@hedgedoc/codemirror-5/addon/edit/closebrackets.js'
+import '@hedgedoc/codemirror-5/addon/edit/closetag.js'
+import '@hedgedoc/codemirror-5/addon/edit/continuelist.js'
+import '@hedgedoc/codemirror-5/addon/edit/matchbrackets.js'
+import '@hedgedoc/codemirror-5/addon/edit/matchtags.js'
+import '@hedgedoc/codemirror-5/addon/fold/brace-fold.js'
+import '@hedgedoc/codemirror-5/addon/fold/foldcode.js'
+import '@hedgedoc/codemirror-5/addon/fold/foldgutter.js'
+import '@hedgedoc/codemirror-5/addon/fold/markdown-fold.js'
+import '@hedgedoc/codemirror-5/addon/fold/xml-fold.js'
+import '@hedgedoc/codemirror-5/addon/merge/merge.js'
+import '@hedgedoc/codemirror-5/addon/mode/multiplex.js'
+import '@hedgedoc/codemirror-5/addon/mode/overlay.js'
+import '@hedgedoc/codemirror-5/addon/mode/simple.js'
+import '@hedgedoc/codemirror-5/addon/scroll/annotatescrollbar.js'
+import '@hedgedoc/codemirror-5/addon/scroll/simplescrollbars.js'
+import '@hedgedoc/codemirror-5/addon/search/jump-to-line.js'
+import '@hedgedoc/codemirror-5/addon/search/match-highlighter.js'
+import '@hedgedoc/codemirror-5/addon/search/matchesonscrollbar.js'
+import '@hedgedoc/codemirror-5/addon/search/search.js'
+import '@hedgedoc/codemirror-5/addon/search/searchcursor.js'
+import '@hedgedoc/codemirror-5/addon/selection/active-line.js'
+import '@hedgedoc/codemirror-5/addon/wrap/hardwrap.js'
+import '@hedgedoc/codemirror-5/keymap/emacs.js'
+import '@hedgedoc/codemirror-5/keymap/sublime.js'
+import '@hedgedoc/codemirror-5/keymap/vim.js'
+import '@hedgedoc/codemirror-5/mode/clike/clike.js'
+import '@hedgedoc/codemirror-5/mode/clojure/clojure.js'
+import '@hedgedoc/codemirror-5/mode/cmake/cmake.js'
+import '@hedgedoc/codemirror-5/mode/coffeescript/coffeescript.js'
+import '@hedgedoc/codemirror-5/mode/css/css.js'
+import '@hedgedoc/codemirror-5/mode/csv/csv.js'
+import '@hedgedoc/codemirror-5/mode/diff/diff.js'
+import '@hedgedoc/codemirror-5/mode/dockerfile/dockerfile.js'
+import '@hedgedoc/codemirror-5/mode/gfm/gfm.js'
+import '@hedgedoc/codemirror-5/mode/gherkin/gherkin.js'
+import '@hedgedoc/codemirror-5/mode/go/go.js'
+import '@hedgedoc/codemirror-5/mode/graphviz/graphviz.js'
+import '@hedgedoc/codemirror-5/mode/groovy/groovy.js'
+import '@hedgedoc/codemirror-5/mode/haskell/haskell.js'
+import '@hedgedoc/codemirror-5/mode/htmlembedded/htmlembedded.js'
+import '@hedgedoc/codemirror-5/mode/htmlmixed/htmlmixed.js'
+import '@hedgedoc/codemirror-5/mode/javascript/javascript.js'
+import '@hedgedoc/codemirror-5/mode/jsx/jsx.js'
+import '@hedgedoc/codemirror-5/mode/lua/lua.js'
+import '@hedgedoc/codemirror-5/mode/markdown/markdown_math.js'
+import '@hedgedoc/codemirror-5/mode/mediawiki/mediawiki.js'
+import '@hedgedoc/codemirror-5/mode/mermaid/mermaid.js'
+import '@hedgedoc/codemirror-5/mode/mllike/mllike.js'
+import '@hedgedoc/codemirror-5/mode/nginx/nginx.js'
+import '@hedgedoc/codemirror-5/mode/perl/perl.js'
+import '@hedgedoc/codemirror-5/mode/php/php.js'
+import '@hedgedoc/codemirror-5/mode/plantuml/plantuml.js'
+import '@hedgedoc/codemirror-5/mode/protobuf/protobuf.js'
+import '@hedgedoc/codemirror-5/mode/pug/pug.js'
+import '@hedgedoc/codemirror-5/mode/python/python.js'
+import '@hedgedoc/codemirror-5/mode/r/r.js'
+import '@hedgedoc/codemirror-5/mode/ruby/ruby.js'
+import '@hedgedoc/codemirror-5/mode/rust/rust.js'
+import '@hedgedoc/codemirror-5/mode/sas/sas.js'
+import '@hedgedoc/codemirror-5/mode/sass/sass.js'
+import '@hedgedoc/codemirror-5/mode/shell/shell.js'
+import '@hedgedoc/codemirror-5/mode/solidity/solidity.js'
+import '@hedgedoc/codemirror-5/mode/sql/sql.js'
+import '@hedgedoc/codemirror-5/mode/stex/stex.js'
+import '@hedgedoc/codemirror-5/mode/swift/swift.js'
+import '@hedgedoc/codemirror-5/mode/tiddlywiki/tiddlywiki.js'
+import '@hedgedoc/codemirror-5/mode/typescript/typescript.js'
+import '@hedgedoc/codemirror-5/mode/vb/vb.js'
+import '@hedgedoc/codemirror-5/mode/verilog/verilog.js'
+import '@hedgedoc/codemirror-5/mode/vhdl/vhdl.js'
+import '@hedgedoc/codemirror-5/mode/xml/xml.js'
+import '@hedgedoc/codemirror-5/mode/yaml-frontmatter/yaml-frontmatter.js'
+import '@hedgedoc/codemirror-5/mode/yaml/yaml.js'
 import '../../../vendor/codemirror-spell-checker/spell-checker.min.js'
 
 import '../../../vendor/inlineAttachment/inline-attachment'
